#[non_exhaustive]pub enum AxisUse {
Ignore,
X,
Y,
Pressure,
Xtilt,
Ytilt,
Wheel,
Distance,
Rotation,
Slider,
Last,
}Expand description
An enumeration describing the way in which a device axis (valuator) maps onto the predefined valuator types that GTK+ understands.
Note that the X and Y axes are not really needed; pointer devices report their location via the x/y members of events regardless. Whether X and Y are present as axes depends on the GDK backend.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Ignore
the axis is ignored.
X
the axis is used as the x axis.
Y
the axis is used as the y axis.
Pressure
the axis is used for pressure information.
Xtilt
the axis is used for x tilt information.
Ytilt
the axis is used for y tilt information.
Wheel
the axis is used for wheel information.
Distance
the axis is used for pen/tablet distance information. (Since: 3.22)
Rotation
the axis is used for pen rotation information. (Since: 3.22)
Slider
the axis is used for pen slider information. (Since: 3.22)
Last
a constant equal to the numerically highest axis value.