#[non_exhaustive]pub enum DeviceType {
Master,
Slave,
Floating,
}Expand description
Indicates the device type. See [above][GdkDeviceManager.description] for more information about the meaning of these device types.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Master
Device is a master (or virtual) device. There will be an associated focus indicator on the screen.
Slave
Device is a slave (or physical) device.
Floating
Device is a physical device, currently not attached to any virtual device.