#[non_exhaustive]pub enum Gravity {
NorthWest,
North,
NorthEast,
West,
Center,
East,
SouthWest,
South,
SouthEast,
Static,
}Expand description
Defines the reference point of a window and the meaning of coordinates
passed to gtk_window_move(). See gtk_window_move() and the “implementation
notes” section of the
Extended Window Manager Hints
specification for more details.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
NorthWest
the reference point is at the top left corner.
North
the reference point is in the middle of the top edge.
NorthEast
the reference point is at the top right corner.
West
the reference point is at the middle of the left edge.
Center
the reference point is at the center of the window.
East
the reference point is at the middle of the right edge.
SouthWest
the reference point is at the lower left corner.
South
the reference point is at the middle of the lower edge.
SouthEast
the reference point is at the lower right corner.
Static
the reference point is at the top left corner of the window itself, ignoring window manager decorations.