#[non_exhaustive]pub enum InputMode {
Disabled,
Screen,
Window,
}Expand description
An enumeration that describes the mode of an input device.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Disabled
the device is disabled and will not report any events.
Screen
the device is enabled. The device’s coordinate space maps to the entire screen.
Window
the device is enabled. The device’s coordinate space is mapped to a single window. The manner in which this window is chosen is undefined, but it will typically be the same way in which the focus window for key events is determined.