#[non_exhaustive]pub enum InputSource {
Mouse,
Pen,
Eraser,
Cursor,
Keyboard,
Touchscreen,
Touchpad,
Trackpoint,
TabletPad,
}Expand description
An enumeration describing the type of an input device in general terms.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Mouse
the device is a mouse. (This will be reported for the core pointer, even if it is something else, such as a trackball.)
Pen
the device is a stylus of a graphics tablet or similar device.
Eraser
the device is an eraser. Typically, this would be the other end of a stylus on a graphics tablet.
Cursor
the device is a graphics tablet “puck” or similar device.
Keyboard
the device is a keyboard.
Touchscreen
the device is a direct-input touch device, such as a touchscreen or tablet. This device type has been added in 3.4.
Touchpad
the device is an indirect touch device, such as a touchpad. This device type has been added in 3.4.
Trackpoint
the device is a trackpoint. This device type has been added in 3.22
TabletPad
the device is a “pad”, a collection of buttons, rings and strips found in drawing tablets. This device type has been added in 3.22.