#[non_exhaustive]pub enum VisualType {
StaticGray,
Grayscale,
StaticColor,
PseudoColor,
TrueColor,
DirectColor,
}Expand description
A set of values that describe the manner in which the pixel values for a visual are converted into RGB values for display.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
StaticGray
Each pixel value indexes a grayscale value directly.
Grayscale
Each pixel is an index into a color map that maps pixel values into grayscale values. The color map can be changed by an application.
StaticColor
Each pixel value is an index into a predefined, unmodifiable color map that maps pixel values into RGB values.
PseudoColor
Each pixel is an index into a color map that maps pixel values into rgb values. The color map can be changed by an application.
TrueColor
Each pixel value directly contains red, green,
and blue components. Use Visual::red_pixel_details(), etc,
to obtain information about how the components are assembled into
a pixel value.
DirectColor
Each pixel value contains red, green, and blue
components as for TrueColor, but the components are
mapped via a color table into the final output table instead of
being converted directly.