#[non_exhaustive]pub enum WindowType {
Root,
Toplevel,
Child,
Temp,
Foreign,
Offscreen,
Subsurface,
}Expand description
Describes the kind of window.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Root
root window; this window has no parent, covers the entire screen, and is created by the window system
Toplevel
toplevel window (used to implement GtkWindow)
Child
child window (used to implement e.g. GtkEntry)
Temp
override redirect temporary window (used to implement
GtkMenu)
Foreign
foreign window (see gdk_window_foreign_new())
Offscreen
offscreen window (see [Offscreen Windows][OFFSCREEN-WINDOWS]). Since 2.18
Subsurface
subsurface-based window; This window is visually tied to a toplevel, and is moved/stacked with it. Currently this window type is only implemented in Wayland. Since 3.14