display_arg_name

Function display_arg_name 

pub fn display_arg_name() -> Option<GString>
Gets the display name specified in the command line arguments passed to gdk_init() or gdk_parse_args(), if any.

Returns

the display name, if specified explicitly, otherwise None this string is owned by GTK+ and must not be modified or freed.