error_trap_pop_ignored

Function error_trap_pop_ignored 

pub fn error_trap_pop_ignored()
Removes an error trap pushed with error_trap_push(), but without bothering to wait and see whether an error occurred. If an error arrives later asynchronously that was triggered while the trap was pushed, that error will be ignored.