pub fn error_trap_push()Expand description
gdk_error_trap_push ();
// … Call the X function which may cause an error here …
if (gdk_error_trap_pop ()) { // … Handle the error here … } ]|
pub fn error_trap_push()gdk_error_trap_push ();
// … Call the X function which may cause an error here …
if (gdk_error_trap_pop ()) { // … Handle the error here … } ]|