events_get_angle

Function events_get_angle 

pub fn events_get_angle(event1: &mut Event, event2: &mut Event) -> Option<f64>
If both events contain X/Y information, this function will return true and return in angle the relative angle from event1 to event2. The rotation direction for positive angles is from the positive X axis towards the positive Y axis.

event1

first GdkEvent

event2

second GdkEvent

Returns

true if the angle could be calculated.

angle

return location for the relative angle between both events