pixbuf_get_from_surface

Function pixbuf_get_from_surface 

pub fn pixbuf_get_from_surface(
    surface: &Surface,
    src_x: i32,
    src_y: i32,
    width: i32,
    height: i32,
) -> Option<Pixbuf>
Transfers image data from a cairo::Surface and converts it to an RGB(A) representation inside a gdk_pixbuf::Pixbuf. This allows you to efficiently read individual pixels from cairo surfaces. For GdkWindows, use gdk_pixbuf_get_from_window() instead.

This function will create an RGB pixbuf with 8 bits per channel. The pixbuf will contain an alpha channel if the surface contains one.

surface

surface to copy from

src_x

Source X coordinate within surface

src_y

Source Y coordinate within surface

width

Width in pixels of region to get

height

Height in pixels of region to get

Returns

A newly-created pixbuf with a reference count of 1, or None on error