program_class

Function program_class 

pub fn program_class() -> Option<GString>
Gets the program class. Unless the program class has explicitly been set with set_program_class() or with the --class commandline option, the default value is the program name (determined with g_get_prgname()) with the first character converted to uppercase.

Returns

the program class.