selection_convert

Function selection_convert 

pub fn selection_convert(
    requestor: &Window,
    selection: &Atom,
    target: &Atom,
    time_: u32,
)
Retrieves the contents of a selection in a given form.

requestor

a Window.

selection

an atom identifying the selection to get the contents of.

target

the form in which to retrieve the selection.

time_

the timestamp to use when retrieving the selection. The selection owner may refuse the request if it did not own the selection at the time indicated by the timestamp.