selection_owner_set_for_display

Function selection_owner_set_for_display 

pub fn selection_owner_set_for_display(
    display: &Display,
    owner: Option<&Window>,
    selection: &Atom,
    time_: u32,
    send_event: bool,
) -> bool
Sets the Window owner as the current owner of the selection selection.

display

the Display

owner

a Window or None to indicate that the owner for the given should be unset

selection

an atom identifying a selection

time_

timestamp to use when setting the selection If this is older than the timestamp given last time the owner was set for the given selection, the request will be ignored

send_event

if true, and the new owner is different from the current owner, the current owner will be sent a SelectionClear event

Returns

true if the selection owner was successfully changed to owner, otherwise false.