set_double_click_time

Function set_double_click_time 

pub fn set_double_click_time(msec: u32)
Set the double click time for the default display. See Display::set_double_click_time(). See also Display::set_double_click_distance(). Applications should not set this, it is a global user-configured setting.

msec

double click time in milliseconds (thousandths of a second)