set_program_class

Function set_program_class 

pub fn set_program_class(program_class: &str)
Sets the program class. The X11 backend uses the program class to set the class name part of the WM_CLASS property on toplevel windows; see the ICCCM.

The program class can still be overridden with the –class command line option.

program_class

a string.