test_render_sync

Function test_render_sync 

pub fn test_render_sync(window: &Window)
Retrieves a pixel from window to force the windowing system to carry out any pending rendering commands.

This function is intended to be used to synchronize with rendering pipelines, to benchmark windowing system rendering operations.

window

a mapped Window