Struct gdk::AnchorHints
source · [−]pub struct AnchorHints { /* private fields */ }Implementations
sourceimpl AnchorHints
impl AnchorHints
pub const FLIP_X: AnchorHints = _
pub const FLIP_Y: AnchorHints = _
pub const SLIDE_X: AnchorHints = _
pub const SLIDE_Y: AnchorHints = _
pub const RESIZE_X: AnchorHints = _
pub const RESIZE_Y: AnchorHints = _
pub const FLIP: AnchorHints = _
pub const SLIDE: AnchorHints = _
pub const RESIZE: AnchorHints = _
sourcepub const fn empty() -> AnchorHints
pub const fn empty() -> AnchorHints
Returns an empty set of flags
sourcepub const fn all() -> AnchorHints
pub const fn all() -> AnchorHints
Returns the set containing all flags.
sourcepub fn from_bits(bits: u32) -> Option<AnchorHints>
pub fn from_bits(bits: u32) -> Option<AnchorHints>
Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.
sourcepub const fn from_bits_truncate(bits: u32) -> AnchorHints
pub const fn from_bits_truncate(bits: u32) -> AnchorHints
Convert from underlying bit representation, dropping any bits that do not correspond to flags.
sourcepub const unsafe fn from_bits_unchecked(bits: u32) -> AnchorHints
pub const unsafe fn from_bits_unchecked(bits: u32) -> AnchorHints
Convert from underlying bit representation, preserving all bits (even those not corresponding to a defined flag).
sourcepub const fn intersects(&self, other: AnchorHints) -> bool
pub const fn intersects(&self, other: AnchorHints) -> bool
Returns true if there are flags common to both self and other.
sourcepub const fn contains(&self, other: AnchorHints) -> bool
pub const fn contains(&self, other: AnchorHints) -> bool
Returns true all of the flags in other are contained within self.
sourcepub fn insert(&mut self, other: AnchorHints)
pub fn insert(&mut self, other: AnchorHints)
Inserts the specified flags in-place.
sourcepub fn remove(&mut self, other: AnchorHints)
pub fn remove(&mut self, other: AnchorHints)
Removes the specified flags in-place.
sourcepub fn toggle(&mut self, other: AnchorHints)
pub fn toggle(&mut self, other: AnchorHints)
Toggles the specified flags in-place.
sourcepub fn set(&mut self, other: AnchorHints, value: bool)
pub fn set(&mut self, other: AnchorHints, value: bool)
Inserts or removes the specified flags depending on the passed value.