pub struct AxisFlags { /* private fields */ }Implementations
sourceimpl AxisFlags
impl AxisFlags
pub const X: AxisFlags = _
pub const Y: AxisFlags = _
pub const PRESSURE: AxisFlags = _
pub const XTILT: AxisFlags = _
pub const YTILT: AxisFlags = _
pub const WHEEL: AxisFlags = _
pub const DISTANCE: AxisFlags = _
pub const ROTATION: AxisFlags = _
pub const SLIDER: AxisFlags = _
sourcepub fn from_bits(bits: u32) -> Option<AxisFlags>
pub fn from_bits(bits: u32) -> Option<AxisFlags>
Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.
sourcepub const fn from_bits_truncate(bits: u32) -> AxisFlags
pub const fn from_bits_truncate(bits: u32) -> AxisFlags
Convert from underlying bit representation, dropping any bits that do not correspond to flags.
sourcepub const unsafe fn from_bits_unchecked(bits: u32) -> AxisFlags
pub const unsafe fn from_bits_unchecked(bits: u32) -> AxisFlags
Convert from underlying bit representation, preserving all bits (even those not corresponding to a defined flag).
sourcepub const fn intersects(&self, other: AxisFlags) -> bool
pub const fn intersects(&self, other: AxisFlags) -> bool
Returns true if there are flags common to both self and other.