pub struct Cursor { /* private fields */ }Expand description
Implementations
Sourceimpl Cursor
impl Cursor
Sourcepub fn for_display(display: &Display, cursor_type: CursorType) -> Option<Cursor>
pub fn for_display(display: &Display, cursor_type: CursorType) -> Option<Cursor>
Sourcepub fn from_name(display: &Display, name: &str) -> Option<Cursor>
pub fn from_name(display: &Display, name: &str) -> Option<Cursor>
Creates a new cursor by looking up name in the current cursor
theme.
A recommended set of cursor names that will work across different platforms can be found in the CSS specification:
- “none”
“default”
“help”
“pointer”
“context-menu”
“progress”
“wait”
“cell”
“crosshair”
“text”
“vertical-text”
“alias”
“copy”
“no-drop”
“move”
“not-allowed”
“grab”
“grabbing”
“all-scroll”
“col-resize”
“row-resize”
“n-resize”
“e-resize”
“s-resize”
“w-resize”
“ne-resize”
“nw-resize”
“sw-resize”
“se-resize”
“ew-resize”
“ns-resize”
“nesw-resize”
“nwse-resize”
“zoom-in”
“zoom-out”
display
the Display for which the cursor will be created
name
the name of the cursor
Returns
a new Cursor, or None if there is no
cursor with the given name
Sourcepub fn from_pixbuf(display: &Display, pixbuf: &Pixbuf, x: i32, y: i32) -> Cursor
pub fn from_pixbuf(display: &Display, pixbuf: &Pixbuf, x: i32, y: i32) -> Cursor
Creates a new cursor from a pixbuf.
Not all GDK backends support RGBA cursors. If they are not
supported, a monochrome approximation will be displayed.
The functions Display::supports_cursor_alpha() and
Display::supports_cursor_color() can be used to determine
whether RGBA cursors are supported;
Display::default_cursor_size() and
Display::maximal_cursor_size() give information about
cursor sizes.
If x or y are -1, the pixbuf must have
options named “x_hot” and “y_hot”, resp., containing
integer values between 0 and the width resp. height of
the pixbuf. (Since: 3.0)
On the X backend, support for RGBA cursors requires a sufficently new version of the X Render extension.
display
the Display for which the cursor will be created
pixbuf
the gdk_pixbuf::Pixbuf containing the cursor image
x
the horizontal offset of the “hotspot” of the cursor.
y
the vertical offset of the “hotspot” of the cursor.
Returns
a new Cursor.
Sourcepub fn from_surface(
display: &Display,
surface: &Surface,
x: f64,
y: f64,
) -> Cursor
pub fn from_surface( display: &Display, surface: &Surface, x: f64, y: f64, ) -> Cursor
Creates a new cursor from a cairo image surface.
Not all GDK backends support RGBA cursors. If they are not
supported, a monochrome approximation will be displayed.
The functions Display::supports_cursor_alpha() and
Display::supports_cursor_color() can be used to determine
whether RGBA cursors are supported;
Display::default_cursor_size() and
Display::maximal_cursor_size() give information about
cursor sizes.
On the X backend, support for RGBA cursors requires a sufficently new version of the X Render extension.
display
the Display for which the cursor will be created
surface
the cairo image surface containing the cursor pixel data
x
the horizontal offset of the “hotspot” of the cursor
y
the vertical offset of the “hotspot” of the cursor
Returns
a new Cursor.
Sourcepub fn cursor_type(&self) -> CursorType
pub fn cursor_type(&self) -> CursorType
Sourcepub fn image(&self) -> Option<Pixbuf>
pub fn image(&self) -> Option<Pixbuf>
Returns a gdk_pixbuf::Pixbuf with the image used to display the cursor.
Note that depending on the capabilities of the windowing system and
on the cursor, GDK may not be able to obtain the image data. In this
case, None is returned.
Returns
a gdk_pixbuf::Pixbuf representing
self, or None
Sourcepub fn surface(&self) -> (Option<Surface>, f64, f64)
pub fn surface(&self) -> (Option<Surface>, f64, f64)
Returns a cairo image surface with the image used to display the cursor.
Note that depending on the capabilities of the windowing system and
on the cursor, GDK may not be able to obtain the image data. In this
case, None is returned.
Returns
a cairo::Surface
representing self, or None
x_hot
Location to store the hotspot x position,
or None
y_hot
Location to store the hotspot y position,
or None