pub struct DevicePad { /* private fields */ }Expand description
DevicePad is an interface implemented by devices of type
InputSource::TabletPad, it allows querying the features provided
by the pad device.
Tablet pads may contain one or more groups, each containing a subset
of the buttons/rings/strips available. DevicePadExt::n_groups()
can be used to obtain the number of groups, DevicePadExt::n_features()
and DevicePadExt::feature_group() can be combined to find out the
number of buttons/rings/strips the device has, and how are they grouped.
Each of those groups have different modes, which may be used to map
each individual pad feature to multiple actions. Only one mode is
effective (current) for each given group, different groups may have
different current modes. The number of available modes in a group can
be found out through DevicePadExt::group_n_modes(), and the current
mode for a given group will be notified through the EventPadGroupMode
event.
Implements
Implementations