Struct gdk::DragAction
source · [−]pub struct DragAction { /* private fields */ }Implementations
sourceimpl DragAction
impl DragAction
pub const DEFAULT: DragAction = _
pub const COPY: DragAction = _
pub const MOVE: DragAction = _
pub const LINK: DragAction = _
pub const PRIVATE: DragAction = _
pub const ASK: DragAction = _
sourcepub const fn empty() -> DragAction
pub const fn empty() -> DragAction
Returns an empty set of flags
sourcepub const fn all() -> DragAction
pub const fn all() -> DragAction
Returns the set containing all flags.
sourcepub fn from_bits(bits: u32) -> Option<DragAction>
pub fn from_bits(bits: u32) -> Option<DragAction>
Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.
sourcepub const fn from_bits_truncate(bits: u32) -> DragAction
pub const fn from_bits_truncate(bits: u32) -> DragAction
Convert from underlying bit representation, dropping any bits that do not correspond to flags.
sourcepub const unsafe fn from_bits_unchecked(bits: u32) -> DragAction
pub const unsafe fn from_bits_unchecked(bits: u32) -> DragAction
Convert from underlying bit representation, preserving all bits (even those not corresponding to a defined flag).
sourcepub const fn intersects(&self, other: DragAction) -> bool
pub const fn intersects(&self, other: DragAction) -> bool
Returns true if there are flags common to both self and other.
sourcepub const fn contains(&self, other: DragAction) -> bool
pub const fn contains(&self, other: DragAction) -> bool
Returns true all of the flags in other are contained within self.
sourcepub fn insert(&mut self, other: DragAction)
pub fn insert(&mut self, other: DragAction)
Inserts the specified flags in-place.
sourcepub fn remove(&mut self, other: DragAction)
pub fn remove(&mut self, other: DragAction)
Removes the specified flags in-place.
sourcepub fn toggle(&mut self, other: DragAction)
pub fn toggle(&mut self, other: DragAction)
Toggles the specified flags in-place.
sourcepub fn set(&mut self, other: DragAction, value: bool)
pub fn set(&mut self, other: DragAction, value: bool)
Inserts or removes the specified flags depending on the passed value.