pub struct DrawingContext { /* private fields */ }Expand description
DrawingContext is an object that represents the current drawing
state of a Window.
It’s possible to use a DrawingContext to draw on a Window
via rendering API like Cairo or OpenGL.
A DrawingContext can only be created by calling Window::begin_draw_frame()
and will be valid until a call to Window::end_draw_frame().
DrawingContext is available since GDK 3.22
Properties
clip
The clip region applied to the drawing context.
Readable | Writeable | Construct Only
window
The Window that created the drawing context.
Readable | Writeable | Construct Only
Implementations
Sourceimpl DrawingContext
impl DrawingContext
Sourcepub fn cairo_context(&self) -> Option<Context>
pub fn cairo_context(&self) -> Option<Context>
Retrieves a Cairo context to be used to draw on the Window
that created the DrawingContext.
The returned context is guaranteed to be valid as long as the
DrawingContext is valid, that is between a call to
Window::begin_draw_frame() and Window::end_draw_frame().
Returns
a Cairo context to be used to draw
the contents of the Window. The context is owned by the
DrawingContext and should not be destroyed