EventGrabBroken

Struct EventGrabBroken 

pub struct EventGrabBroken(/* private fields */);
Generated when a pointer or keyboard grab is broken. On X11, this happens when the grab window becomes unviewable (i.e. it or one of its ancestors is unmapped), or if the same application grabs the pointer or keyboard again. Note that implicit grabs (which are initiated by button presses) can also cause EventGrabBroken events.

Implementations

Methods from Deref<Target = Event>

pub fn as_ptr(&self) -> *mut GdkEvent

Return the inner pointer to the underlying C value.

pub fn put(&self)

pub fn axis(&self, axis_use: AxisUse) -> Option<f64>

pub fn button(&self) -> Option<u32>

pub fn click_count(&self) -> Option<u32>

pub fn coords(&self) -> Option<(f64, f64)>

pub fn keycode(&self) -> Option<u16>

pub fn keyval(&self) -> Option<u32>

pub fn root_coords(&self) -> Option<(f64, f64)>

pub fn scroll_direction(&self) -> Option<ScrollDirection>

pub fn scroll_deltas(&self) -> Option<(f64, f64)>

pub fn is_scroll_stop_event(&self) -> bool

pub fn state(&self) -> Option<ModifierType>

pub fn time(&self) -> u32

pub fn window(&self) -> Option<Window>

Returns the associated Window if applicable.

pub fn event_sequence(&self) -> Option<EventSequence>

pub fn triggers_context_menu(&self) -> bool

pub fn seat(&self) -> Option<Seat>

pub fn scancode(&self) -> i32

pub fn is_pointer_emulated(&self) -> bool

pub fn set_screen(&mut self, screen: Option<&Screen>)

pub fn screen(&self) -> Option<Screen>

pub fn set_device(&mut self, device: Option<&Device>)

pub fn device(&self) -> Option<Device>

pub fn set_source_device(&mut self, device: Option<&Device>)

pub fn source_device(&self) -> Option<Device>

pub fn set_device_tool(&mut self, device: Option<&DeviceTool>)

pub fn device_tool(&self) -> Option<DeviceTool>

pub fn event_type(&self) -> EventType

Returns the event type.

pub fn is_send_event(&self) -> bool

Returns whether the event was sent explicitly.

pub fn is<T: FromEvent>(&self) -> bool

Returns true if the event type matches T.

pub fn downcast_ref<T: FromEvent>(&self) -> Option<&T>

Tries to downcast to a specific event type.

pub fn downcast_mut<T: FromEvent>(&mut self) -> Option<&mut T>

Tries to downcast to a specific event type.