pub struct EventMask { /* private fields */ }Implementations
sourceimpl EventMask
impl EventMask
pub const EXPOSURE_MASK: EventMask = _
pub const POINTER_MOTION_MASK: EventMask = _
pub const POINTER_MOTION_HINT_MASK: EventMask = _
pub const BUTTON_MOTION_MASK: EventMask = _
pub const BUTTON1_MOTION_MASK: EventMask = _
pub const BUTTON2_MOTION_MASK: EventMask = _
pub const BUTTON3_MOTION_MASK: EventMask = _
pub const BUTTON_PRESS_MASK: EventMask = _
pub const BUTTON_RELEASE_MASK: EventMask = _
pub const KEY_PRESS_MASK: EventMask = _
pub const KEY_RELEASE_MASK: EventMask = _
pub const ENTER_NOTIFY_MASK: EventMask = _
pub const LEAVE_NOTIFY_MASK: EventMask = _
pub const FOCUS_CHANGE_MASK: EventMask = _
pub const STRUCTURE_MASK: EventMask = _
pub const PROPERTY_CHANGE_MASK: EventMask = _
pub const VISIBILITY_NOTIFY_MASK: EventMask = _
pub const PROXIMITY_IN_MASK: EventMask = _
pub const PROXIMITY_OUT_MASK: EventMask = _
pub const SUBSTRUCTURE_MASK: EventMask = _
pub const SCROLL_MASK: EventMask = _
pub const TOUCH_MASK: EventMask = _
pub const SMOOTH_SCROLL_MASK: EventMask = _
pub const TOUCHPAD_GESTURE_MASK: EventMask = _
pub const TABLET_PAD_MASK: EventMask = _
pub const ALL_EVENTS_MASK: EventMask = _
sourcepub fn from_bits(bits: u32) -> Option<EventMask>
pub fn from_bits(bits: u32) -> Option<EventMask>
Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.
sourcepub const fn from_bits_truncate(bits: u32) -> EventMask
pub const fn from_bits_truncate(bits: u32) -> EventMask
Convert from underlying bit representation, dropping any bits that do not correspond to flags.
sourcepub const unsafe fn from_bits_unchecked(bits: u32) -> EventMask
pub const unsafe fn from_bits_unchecked(bits: u32) -> EventMask
Convert from underlying bit representation, preserving all bits (even those not corresponding to a defined flag).
sourcepub const fn intersects(&self, other: EventMask) -> bool
pub const fn intersects(&self, other: EventMask) -> bool
Returns true if there are flags common to both self and other.