Struct gdk::FrameClockPhase
source · [−]pub struct FrameClockPhase { /* private fields */ }Implementations
sourceimpl FrameClockPhase
impl FrameClockPhase
pub const NONE: FrameClockPhase = _
pub const FLUSH_EVENTS: FrameClockPhase = _
pub const BEFORE_PAINT: FrameClockPhase = _
pub const UPDATE: FrameClockPhase = _
pub const LAYOUT: FrameClockPhase = _
pub const PAINT: FrameClockPhase = _
pub const RESUME_EVENTS: FrameClockPhase = _
pub const AFTER_PAINT: FrameClockPhase = _
sourcepub const fn empty() -> FrameClockPhase
pub const fn empty() -> FrameClockPhase
Returns an empty set of flags
sourcepub const fn all() -> FrameClockPhase
pub const fn all() -> FrameClockPhase
Returns the set containing all flags.
sourcepub fn from_bits(bits: u32) -> Option<FrameClockPhase>
pub fn from_bits(bits: u32) -> Option<FrameClockPhase>
Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.
sourcepub const fn from_bits_truncate(bits: u32) -> FrameClockPhase
pub const fn from_bits_truncate(bits: u32) -> FrameClockPhase
Convert from underlying bit representation, dropping any bits that do not correspond to flags.
sourcepub const unsafe fn from_bits_unchecked(bits: u32) -> FrameClockPhase
pub const unsafe fn from_bits_unchecked(bits: u32) -> FrameClockPhase
Convert from underlying bit representation, preserving all bits (even those not corresponding to a defined flag).
sourcepub const fn intersects(&self, other: FrameClockPhase) -> bool
pub const fn intersects(&self, other: FrameClockPhase) -> bool
Returns true if there are flags common to both self and other.
sourcepub const fn contains(&self, other: FrameClockPhase) -> bool
pub const fn contains(&self, other: FrameClockPhase) -> bool
Returns true all of the flags in other are contained within self.
sourcepub fn insert(&mut self, other: FrameClockPhase)
pub fn insert(&mut self, other: FrameClockPhase)
Inserts the specified flags in-place.
sourcepub fn remove(&mut self, other: FrameClockPhase)
pub fn remove(&mut self, other: FrameClockPhase)
Removes the specified flags in-place.
sourcepub fn toggle(&mut self, other: FrameClockPhase)
pub fn toggle(&mut self, other: FrameClockPhase)
Toggles the specified flags in-place.
sourcepub fn set(&mut self, other: FrameClockPhase, value: bool)
pub fn set(&mut self, other: FrameClockPhase, value: bool)
Inserts or removes the specified flags depending on the passed value.