Struct gdk::ModifierType
source · [−]pub struct ModifierType { /* private fields */ }Implementations
sourceimpl ModifierType
impl ModifierType
pub const SHIFT_MASK: ModifierType = _
pub const LOCK_MASK: ModifierType = _
pub const CONTROL_MASK: ModifierType = _
pub const MOD1_MASK: ModifierType = _
pub const MOD2_MASK: ModifierType = _
pub const MOD3_MASK: ModifierType = _
pub const MOD4_MASK: ModifierType = _
pub const MOD5_MASK: ModifierType = _
pub const BUTTON1_MASK: ModifierType = _
pub const BUTTON2_MASK: ModifierType = _
pub const BUTTON3_MASK: ModifierType = _
pub const BUTTON4_MASK: ModifierType = _
pub const BUTTON5_MASK: ModifierType = _
pub const MODIFIER_RESERVED_13_MASK: ModifierType = _
pub const MODIFIER_RESERVED_14_MASK: ModifierType = _
pub const MODIFIER_RESERVED_15_MASK: ModifierType = _
pub const MODIFIER_RESERVED_16_MASK: ModifierType = _
pub const MODIFIER_RESERVED_17_MASK: ModifierType = _
pub const MODIFIER_RESERVED_18_MASK: ModifierType = _
pub const MODIFIER_RESERVED_19_MASK: ModifierType = _
pub const MODIFIER_RESERVED_20_MASK: ModifierType = _
pub const MODIFIER_RESERVED_21_MASK: ModifierType = _
pub const MODIFIER_RESERVED_22_MASK: ModifierType = _
pub const MODIFIER_RESERVED_23_MASK: ModifierType = _
pub const MODIFIER_RESERVED_24_MASK: ModifierType = _
pub const MODIFIER_RESERVED_25_MASK: ModifierType = _
pub const SUPER_MASK: ModifierType = _
pub const HYPER_MASK: ModifierType = _
pub const META_MASK: ModifierType = _
pub const MODIFIER_RESERVED_29_MASK: ModifierType = _
pub const RELEASE_MASK: ModifierType = _
pub const MODIFIER_MASK: ModifierType = _
sourcepub const fn empty() -> ModifierType
pub const fn empty() -> ModifierType
Returns an empty set of flags
sourcepub const fn all() -> ModifierType
pub const fn all() -> ModifierType
Returns the set containing all flags.
sourcepub fn from_bits(bits: u32) -> Option<ModifierType>
pub fn from_bits(bits: u32) -> Option<ModifierType>
Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.
sourcepub const fn from_bits_truncate(bits: u32) -> ModifierType
pub const fn from_bits_truncate(bits: u32) -> ModifierType
Convert from underlying bit representation, dropping any bits that do not correspond to flags.
sourcepub const unsafe fn from_bits_unchecked(bits: u32) -> ModifierType
pub const unsafe fn from_bits_unchecked(bits: u32) -> ModifierType
Convert from underlying bit representation, preserving all bits (even those not corresponding to a defined flag).
sourcepub const fn intersects(&self, other: ModifierType) -> bool
pub const fn intersects(&self, other: ModifierType) -> bool
Returns true if there are flags common to both self and other.
sourcepub const fn contains(&self, other: ModifierType) -> bool
pub const fn contains(&self, other: ModifierType) -> bool
Returns true all of the flags in other are contained within self.
sourcepub fn insert(&mut self, other: ModifierType)
pub fn insert(&mut self, other: ModifierType)
Inserts the specified flags in-place.
sourcepub fn remove(&mut self, other: ModifierType)
pub fn remove(&mut self, other: ModifierType)
Removes the specified flags in-place.
sourcepub fn toggle(&mut self, other: ModifierType)
pub fn toggle(&mut self, other: ModifierType)
Toggles the specified flags in-place.
sourcepub fn set(&mut self, other: ModifierType, value: bool)
pub fn set(&mut self, other: ModifierType, value: bool)
Inserts or removes the specified flags depending on the passed value.