Struct gdk::SeatCapabilities
source · [−]pub struct SeatCapabilities { /* private fields */ }Implementations
sourceimpl SeatCapabilities
impl SeatCapabilities
pub const NONE: SeatCapabilities = _
pub const POINTER: SeatCapabilities = _
pub const TOUCH: SeatCapabilities = _
pub const TABLET_STYLUS: SeatCapabilities = _
pub const KEYBOARD: SeatCapabilities = _
pub const ALL_POINTING: SeatCapabilities = _
pub const ALL: SeatCapabilities = _
sourcepub const fn empty() -> SeatCapabilities
pub const fn empty() -> SeatCapabilities
Returns an empty set of flags
sourcepub const fn all() -> SeatCapabilities
pub const fn all() -> SeatCapabilities
Returns the set containing all flags.
sourcepub fn from_bits(bits: u32) -> Option<SeatCapabilities>
pub fn from_bits(bits: u32) -> Option<SeatCapabilities>
Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.
sourcepub const fn from_bits_truncate(bits: u32) -> SeatCapabilities
pub const fn from_bits_truncate(bits: u32) -> SeatCapabilities
Convert from underlying bit representation, dropping any bits that do not correspond to flags.
sourcepub const unsafe fn from_bits_unchecked(bits: u32) -> SeatCapabilities
pub const unsafe fn from_bits_unchecked(bits: u32) -> SeatCapabilities
Convert from underlying bit representation, preserving all bits (even those not corresponding to a defined flag).
sourcepub const fn intersects(&self, other: SeatCapabilities) -> bool
pub const fn intersects(&self, other: SeatCapabilities) -> bool
Returns true if there are flags common to both self and other.
sourcepub const fn contains(&self, other: SeatCapabilities) -> bool
pub const fn contains(&self, other: SeatCapabilities) -> bool
Returns true all of the flags in other are contained within self.
sourcepub fn insert(&mut self, other: SeatCapabilities)
pub fn insert(&mut self, other: SeatCapabilities)
Inserts the specified flags in-place.
sourcepub fn remove(&mut self, other: SeatCapabilities)
pub fn remove(&mut self, other: SeatCapabilities)
Removes the specified flags in-place.
sourcepub fn toggle(&mut self, other: SeatCapabilities)
pub fn toggle(&mut self, other: SeatCapabilities)
Toggles the specified flags in-place.
sourcepub fn set(&mut self, other: SeatCapabilities, value: bool)
pub fn set(&mut self, other: SeatCapabilities, value: bool)
Inserts or removes the specified flags depending on the passed value.