Struct gdk::WMDecoration
source · [−]pub struct WMDecoration { /* private fields */ }Implementations
sourceimpl WMDecoration
impl WMDecoration
pub const ALL: WMDecoration = _
pub const BORDER: WMDecoration = _
pub const RESIZEH: WMDecoration = _
pub const TITLE: WMDecoration = _
pub const MENU: WMDecoration = _
pub const MINIMIZE: WMDecoration = _
pub const MAXIMIZE: WMDecoration = _
sourcepub const fn empty() -> WMDecoration
pub const fn empty() -> WMDecoration
Returns an empty set of flags
sourcepub const fn all() -> WMDecoration
pub const fn all() -> WMDecoration
Returns the set containing all flags.
sourcepub fn from_bits(bits: u32) -> Option<WMDecoration>
pub fn from_bits(bits: u32) -> Option<WMDecoration>
Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.
sourcepub const fn from_bits_truncate(bits: u32) -> WMDecoration
pub const fn from_bits_truncate(bits: u32) -> WMDecoration
Convert from underlying bit representation, dropping any bits that do not correspond to flags.
sourcepub const unsafe fn from_bits_unchecked(bits: u32) -> WMDecoration
pub const unsafe fn from_bits_unchecked(bits: u32) -> WMDecoration
Convert from underlying bit representation, preserving all bits (even those not corresponding to a defined flag).
sourcepub const fn intersects(&self, other: WMDecoration) -> bool
pub const fn intersects(&self, other: WMDecoration) -> bool
Returns true if there are flags common to both self and other.
sourcepub const fn contains(&self, other: WMDecoration) -> bool
pub const fn contains(&self, other: WMDecoration) -> bool
Returns true all of the flags in other are contained within self.
sourcepub fn insert(&mut self, other: WMDecoration)
pub fn insert(&mut self, other: WMDecoration)
Inserts the specified flags in-place.
sourcepub fn remove(&mut self, other: WMDecoration)
pub fn remove(&mut self, other: WMDecoration)
Removes the specified flags in-place.
sourcepub fn toggle(&mut self, other: WMDecoration)
pub fn toggle(&mut self, other: WMDecoration)
Toggles the specified flags in-place.
sourcepub fn set(&mut self, other: WMDecoration, value: bool)
pub fn set(&mut self, other: WMDecoration, value: bool)
Inserts or removes the specified flags depending on the passed value.