Struct gdk::WMFunction
source · [−]pub struct WMFunction { /* private fields */ }Implementations
sourceimpl WMFunction
impl WMFunction
pub const ALL: WMFunction = _
pub const RESIZE: WMFunction = _
pub const MOVE: WMFunction = _
pub const MINIMIZE: WMFunction = _
pub const MAXIMIZE: WMFunction = _
pub const CLOSE: WMFunction = _
sourcepub const fn empty() -> WMFunction
pub const fn empty() -> WMFunction
Returns an empty set of flags
sourcepub const fn all() -> WMFunction
pub const fn all() -> WMFunction
Returns the set containing all flags.
sourcepub fn from_bits(bits: u32) -> Option<WMFunction>
pub fn from_bits(bits: u32) -> Option<WMFunction>
Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.
sourcepub const fn from_bits_truncate(bits: u32) -> WMFunction
pub const fn from_bits_truncate(bits: u32) -> WMFunction
Convert from underlying bit representation, dropping any bits that do not correspond to flags.
sourcepub const unsafe fn from_bits_unchecked(bits: u32) -> WMFunction
pub const unsafe fn from_bits_unchecked(bits: u32) -> WMFunction
Convert from underlying bit representation, preserving all bits (even those not corresponding to a defined flag).
sourcepub const fn intersects(&self, other: WMFunction) -> bool
pub const fn intersects(&self, other: WMFunction) -> bool
Returns true if there are flags common to both self and other.
sourcepub const fn contains(&self, other: WMFunction) -> bool
pub const fn contains(&self, other: WMFunction) -> bool
Returns true all of the flags in other are contained within self.
sourcepub fn insert(&mut self, other: WMFunction)
pub fn insert(&mut self, other: WMFunction)
Inserts the specified flags in-place.
sourcepub fn remove(&mut self, other: WMFunction)
pub fn remove(&mut self, other: WMFunction)
Removes the specified flags in-place.
sourcepub fn toggle(&mut self, other: WMFunction)
pub fn toggle(&mut self, other: WMFunction)
Toggles the specified flags in-place.
sourcepub fn set(&mut self, other: WMFunction, value: bool)
pub fn set(&mut self, other: WMFunction, value: bool)
Inserts or removes the specified flags depending on the passed value.