Struct gdk::WindowHints
source · [−]pub struct WindowHints { /* private fields */ }Implementations
sourceimpl WindowHints
impl WindowHints
pub const POS: WindowHints = _
pub const MIN_SIZE: WindowHints = _
pub const MAX_SIZE: WindowHints = _
pub const BASE_SIZE: WindowHints = _
pub const ASPECT: WindowHints = _
pub const RESIZE_INC: WindowHints = _
pub const WIN_GRAVITY: WindowHints = _
pub const USER_POS: WindowHints = _
pub const USER_SIZE: WindowHints = _
sourcepub const fn empty() -> WindowHints
pub const fn empty() -> WindowHints
Returns an empty set of flags
sourcepub const fn all() -> WindowHints
pub const fn all() -> WindowHints
Returns the set containing all flags.
sourcepub fn from_bits(bits: u32) -> Option<WindowHints>
pub fn from_bits(bits: u32) -> Option<WindowHints>
Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.
sourcepub const fn from_bits_truncate(bits: u32) -> WindowHints
pub const fn from_bits_truncate(bits: u32) -> WindowHints
Convert from underlying bit representation, dropping any bits that do not correspond to flags.
sourcepub const unsafe fn from_bits_unchecked(bits: u32) -> WindowHints
pub const unsafe fn from_bits_unchecked(bits: u32) -> WindowHints
Convert from underlying bit representation, preserving all bits (even those not corresponding to a defined flag).
sourcepub const fn intersects(&self, other: WindowHints) -> bool
pub const fn intersects(&self, other: WindowHints) -> bool
Returns true if there are flags common to both self and other.
sourcepub const fn contains(&self, other: WindowHints) -> bool
pub const fn contains(&self, other: WindowHints) -> bool
Returns true all of the flags in other are contained within self.
sourcepub fn insert(&mut self, other: WindowHints)
pub fn insert(&mut self, other: WindowHints)
Inserts the specified flags in-place.
sourcepub fn remove(&mut self, other: WindowHints)
pub fn remove(&mut self, other: WindowHints)
Removes the specified flags in-place.
sourcepub fn toggle(&mut self, other: WindowHints)
pub fn toggle(&mut self, other: WindowHints)
Toggles the specified flags in-place.
sourcepub fn set(&mut self, other: WindowHints, value: bool)
pub fn set(&mut self, other: WindowHints, value: bool)
Inserts or removes the specified flags depending on the passed value.