Struct gdk::WindowState
source · [−]pub struct WindowState { /* private fields */ }Implementations
sourceimpl WindowState
impl WindowState
pub const WITHDRAWN: WindowState = _
pub const ICONIFIED: WindowState = _
pub const MAXIMIZED: WindowState = _
pub const STICKY: WindowState = _
pub const FULLSCREEN: WindowState = _
pub const ABOVE: WindowState = _
pub const BELOW: WindowState = _
pub const FOCUSED: WindowState = _
pub const TILED: WindowState = _
pub const TOP_TILED: WindowState = _
pub const TOP_RESIZABLE: WindowState = _
pub const RIGHT_TILED: WindowState = _
pub const RIGHT_RESIZABLE: WindowState = _
pub const BOTTOM_TILED: WindowState = _
pub const BOTTOM_RESIZABLE: WindowState = _
pub const LEFT_TILED: WindowState = _
pub const LEFT_RESIZABLE: WindowState = _
sourcepub const fn empty() -> WindowState
pub const fn empty() -> WindowState
Returns an empty set of flags
sourcepub const fn all() -> WindowState
pub const fn all() -> WindowState
Returns the set containing all flags.
sourcepub fn from_bits(bits: u32) -> Option<WindowState>
pub fn from_bits(bits: u32) -> Option<WindowState>
Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.
sourcepub const fn from_bits_truncate(bits: u32) -> WindowState
pub const fn from_bits_truncate(bits: u32) -> WindowState
Convert from underlying bit representation, dropping any bits that do not correspond to flags.
sourcepub const unsafe fn from_bits_unchecked(bits: u32) -> WindowState
pub const unsafe fn from_bits_unchecked(bits: u32) -> WindowState
Convert from underlying bit representation, preserving all bits (even those not corresponding to a defined flag).
sourcepub const fn intersects(&self, other: WindowState) -> bool
pub const fn intersects(&self, other: WindowState) -> bool
Returns true if there are flags common to both self and other.
sourcepub const fn contains(&self, other: WindowState) -> bool
pub const fn contains(&self, other: WindowState) -> bool
Returns true all of the flags in other are contained within self.
sourcepub fn insert(&mut self, other: WindowState)
pub fn insert(&mut self, other: WindowState)
Inserts the specified flags in-place.
sourcepub fn remove(&mut self, other: WindowState)
pub fn remove(&mut self, other: WindowState)
Removes the specified flags in-place.
sourcepub fn toggle(&mut self, other: WindowState)
pub fn toggle(&mut self, other: WindowState)
Toggles the specified flags in-place.
sourcepub fn set(&mut self, other: WindowState, value: bool)
pub fn set(&mut self, other: WindowState, value: bool)
Inserts or removes the specified flags depending on the passed value.