pub fn set_allowed_backends(backends: &str)Expand description
gdk_set_allowed_backends (“wayland,quartz,*”); ]| instructs GDK to try the Wayland backend first, followed by the Quartz backend, and then all others.
If the GDK_BACKEND environment variable
is set, it determines what backends are tried in what
order, while still respecting the set of allowed backends
that are specified by this function.
The possible backend names are x11, win32, quartz, broadway, wayland. You can also include a * in the list to try all remaining backends.
This call must happen prior to Display::open(),
gtk_init(), gtk_init_with_args() or gtk_init_check()
in order to take effect.
backends
a comma-separated list of backends