Device

Struct Device 

pub struct Device { /* private fields */ }
The Device object represents a single input device, such as a keyboard, a mouse, a touchpad, etc.

See the DeviceManager documentation for more information about the various kinds of master and slave devices, and their relationships.

This is an Abstract Base Class, you cannot instantiate it.

Properties

associated-device

Associated pointer or keyboard with this device, if any. Devices of type DeviceType::Master always come in keyboard/pointer pairs. Other device types will have a None associated device.

Readable

axes

The axes currently available for this device.

Readable

device-manager

The DeviceManager the Device pertains to.

Readable | Writeable | Construct Only

display

The Display the Device pertains to.

Readable | Writeable | Construct Only

has-cursor

Whether the device is represented by a cursor on the screen. Devices of type DeviceType::Master will have true here.

Readable | Writeable | Construct Only

input-mode

Readable | Writeable

input-source

Source type for the device.

Readable | Writeable | Construct Only

n-axes

Number of axes in the device.

Readable

name

The device name.

Readable | Writeable | Construct Only

num-touches

The maximal number of concurrent touches on a touch device. Will be 0 if the device is not a touch device or if the number of touches is unknown.

Readable | Writeable | Construct Only

product-id

Product ID of this device, see DeviceExt::product_id().

Readable | Writeable | Construct Only

seat

Seat of this device.

Readable | Writeable

tool

Readable

type

Device role in the device manager.

Readable | Writeable | Construct Only

vendor-id

Vendor ID of this device, see DeviceExt::vendor_id().

Readable | Writeable | Construct Only

Signals

changed

The ::changed signal is emitted either when the Device has changed the number of either axes or keys. For example In X this will normally happen when the slave device routing events through the master device changes (for example, user switches from the USB mouse to a tablet), in that case the master device will change to reflect the new slave device axes and keys.

tool-changed

The ::tool-changed signal is emitted on pen/eraser GdkDevices whenever tools enter or leave proximity.

Implements

DeviceExt, DeviceExtManual

Implementations

Source

impl Device

pub const NONE: Option<&'static Device> = None