pub struct Display { /* private fields */ }Expand description
Display objects purpose are two fold:
-
To manage and provide information about input devices (pointers and keyboards)
-
To manage and provide information about the available
GdkScreens
GdkDisplay objects are the GDK representation of an X Display, which can be described as a workstation consisting of a keyboard, a pointing device (such as a mouse) and one or more screens. It is used to open and keep track of various GdkScreen objects currently instantiated by the application. It is also used to access the keyboard(s) and mouse pointer(s) of the display.
Most of the input device handling has been factored out into
the separate DeviceManager object. Every display has a
device manager, which you can obtain using
gdk_display_get_device_manager().
Signals
closed
The ::closed signal is emitted when the connection to the windowing
system for display is closed.
monitor-added
The ::monitor-added signal is emitted whenever a monitor is added.
monitor-removed
The ::monitor-removed signal is emitted whenever a monitor is removed.
opened
The ::opened signal is emitted when the connection to the windowing
system for display is opened.
seat-added
The ::seat-added signal is emitted whenever a new seat is made known to the windowing system.
seat-removed
The ::seat-removed signal is emitted whenever a seat is removed by the windowing system.
Implements
Implementations
Sourceimpl Display
impl Display
Sourcepub fn close(&self)
pub fn close(&self)
Closes the connection to the windowing system for the given display, and cleans up associated resources.
Sourcepub fn device_is_grabbed(&self, device: &impl IsA<Device>) -> bool
pub fn device_is_grabbed(&self, device: &impl IsA<Device>) -> bool
Sourcepub fn flush(&self)
pub fn flush(&self)
Flushes any requests queued for the windowing system; this happens automatically when the main loop blocks waiting for new events, but if your application is drawing without returning control to the main loop, you may need to call this function explicitly. A common case where this function needs to be called is when an application is executing drawing commands from a thread other than the thread where the main loop is running.
This is most useful for X11. On windowing systems where requests are handled synchronously, this function will do nothing.
Sourcepub fn app_launch_context(&self) -> Option<AppLaunchContext>
pub fn app_launch_context(&self) -> Option<AppLaunchContext>
Returns a AppLaunchContext suitable for launching
applications on the given display.
Returns
a new AppLaunchContext for self.
Free with g_object_unref() when done
Sourcepub fn default_cursor_size(&self) -> u32
pub fn default_cursor_size(&self) -> u32
Sourcepub fn default_group(&self) -> Window
pub fn default_group(&self) -> Window
Returns the default group leader window for all toplevel windows
on self. This window is implicitly created by GDK.
See Window::set_group().
Returns
The default group leader window
for self
Sourcepub fn default_screen(&self) -> Screen
pub fn default_screen(&self) -> Screen
Sourcepub fn default_seat(&self) -> Option<Seat>
pub fn default_seat(&self) -> Option<Seat>
Sourcepub fn maximal_cursor_size(&self) -> (u32, u32)
pub fn maximal_cursor_size(&self) -> (u32, u32)
Sourcepub fn monitor_at_window(&self, window: &Window) -> Option<Monitor>
pub fn monitor_at_window(&self, window: &Window) -> Option<Monitor>
Sourcepub fn n_monitors(&self) -> i32
pub fn n_monitors(&self) -> i32
Gets the number of monitors that belong to self.
The returned number is valid until the next emission of the
monitor-added or monitor-removed signal.
Returns
the number of monitors
Sourcepub fn name(&self) -> GString
pub fn name(&self) -> GString
Gets the name of the display.
Returns
a string representing the display name. This string is owned by GDK and should not be modified or freed.
Sourcepub fn primary_monitor(&self) -> Option<Monitor>
pub fn primary_monitor(&self) -> Option<Monitor>
Gets the primary monitor for the display.
The primary monitor is considered the monitor where the “main desktop” lives. While normal application windows typically allow the window manager to place the windows, specialized desktop applications such as panels should place themselves on the primary monitor.
Returns
the primary monitor, or None if no primary
monitor is configured by the user
Sourcepub fn has_pending(&self) -> bool
pub fn has_pending(&self) -> bool
Sourcepub fn list_seats(&self) -> Vec<Seat>
pub fn list_seats(&self) -> Vec<Seat>
Sourcepub fn notify_startup_complete(&self, startup_id: &str)
pub fn notify_startup_complete(&self, startup_id: &str)
Indicates to the GUI environment that the application has finished loading, using a given identifier.
GTK+ will call this function automatically for GtkWindow
with custom startup-notification identifier unless
gtk_window_set_auto_startup_notification() is called to
disable that feature.
startup_id
a startup-notification identifier, for which notification process should be completed
Sourcepub fn peek_event(&self) -> Option<Event>
pub fn peek_event(&self) -> Option<Event>
Gets a copy of the first GdkEvent in the self’s event queue, without
removing the event from the queue. (Note that this function will
not get more events from the windowing system. It only checks the events
that have already been moved to the GDK event queue.)
Returns
a copy of the first GdkEvent on the event
queue, or None if no events are in the queue. The returned
GdkEvent should be freed with gdk_event_free().
Sourcepub fn request_selection_notification(&self, selection: &Atom) -> bool
pub fn request_selection_notification(&self, selection: &Atom) -> bool
Request EventOwnerChange events for ownership changes
of the selection named by the given atom.
selection
the Atom naming the selection for which
ownership change notification is requested
Returns
whether EventOwnerChange events will
be sent.
Sourcepub fn set_double_click_distance(&self, distance: u32)
pub fn set_double_click_distance(&self, distance: u32)
Sets the double click distance (two clicks within this distance
count as a double click and result in a [EventType::_2buttonPress][crate::EventType::_2buttonPress] event).
See also set_double_click_time().
Applications should not set this, it is a global
user-configured setting.
distance
distance in pixels
Sourcepub fn set_double_click_time(&self, msec: u32)
pub fn set_double_click_time(&self, msec: u32)
Sets the double click time (two clicks within this time interval
count as a double click and result in a [EventType::_2buttonPress][crate::EventType::_2buttonPress] event).
Applications should not set this, it is a global
user-configured setting.
msec
double click time in milliseconds (thousandths of a second)
Sourcepub fn store_clipboard(
&self,
clipboard_window: &Window,
time_: u32,
targets: &[Atom],
)
pub fn store_clipboard( &self, clipboard_window: &Window, time_: u32, targets: &[Atom], )
Issues a request to the clipboard manager to store the clipboard data. On X11, this is a special program that works according to the FreeDesktop Clipboard Specification.
clipboard_window
a Window belonging to the clipboard owner
time_
a timestamp
targets
an array of targets
that should be saved, or None
if all available targets should be saved.
Sourcepub fn supports_clipboard_persistence(&self) -> bool
pub fn supports_clipboard_persistence(&self) -> bool
Sourcepub fn supports_cursor_alpha(&self) -> bool
pub fn supports_cursor_alpha(&self) -> bool
Sourcepub fn supports_cursor_color(&self) -> bool
pub fn supports_cursor_color(&self) -> bool
Sourcepub fn supports_input_shapes(&self) -> bool
pub fn supports_input_shapes(&self) -> bool
Sourcepub fn supports_selection_notification(&self) -> bool
pub fn supports_selection_notification(&self) -> bool
Returns whether EventOwnerChange events will be
sent when the owner of a selection changes.
Returns
whether EventOwnerChange events will
be sent.
Sourcepub fn supports_shapes(&self) -> bool
pub fn supports_shapes(&self) -> bool
Sourcepub fn sync(&self)
pub fn sync(&self)
Flushes any requests queued for the windowing system and waits until all
requests have been handled. This is often used for making sure that the
display is synchronized with the current state of the program. Calling
sync() before error_trap_pop() makes sure that any errors
generated from earlier requests are handled before the error trap is
removed.
This is most useful for X11. On windowing systems where requests are handled synchronously, this function will do nothing.
Sourcepub fn connect_closed<F: Fn(&Self, bool) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_closed<F: Fn(&Self, bool) + 'static>( &self, f: F, ) -> SignalHandlerId
Sourcepub fn connect_monitor_added<F: Fn(&Self, &Monitor) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_monitor_added<F: Fn(&Self, &Monitor) + 'static>( &self, f: F, ) -> SignalHandlerId
The ::monitor-added signal is emitted whenever a monitor is added.
monitor
the monitor that was just added
Sourcepub fn connect_monitor_removed<F: Fn(&Self, &Monitor) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_monitor_removed<F: Fn(&Self, &Monitor) + 'static>( &self, f: F, ) -> SignalHandlerId
The ::monitor-removed signal is emitted whenever a monitor is removed.
monitor
the monitor that was just removed
Sourcepub fn connect_opened<F: Fn(&Self) + 'static>(&self, f: F) -> SignalHandlerId
pub fn connect_opened<F: Fn(&Self) + 'static>(&self, f: F) -> SignalHandlerId
The ::opened signal is emitted when the connection to the windowing
system for display is opened.
Sourcepub fn connect_seat_added<F: Fn(&Self, &Seat) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_seat_added<F: Fn(&Self, &Seat) + 'static>( &self, f: F, ) -> SignalHandlerId
The ::seat-added signal is emitted whenever a new seat is made known to the windowing system.
seat
the seat that was just added
Sourcepub fn connect_seat_removed<F: Fn(&Self, &Seat) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_seat_removed<F: Fn(&Self, &Seat) + 'static>( &self, f: F, ) -> SignalHandlerId
The ::seat-removed signal is emitted whenever a seat is removed by the windowing system.
seat
the seat that was just removed