pub struct EventButton(/* private fields */);Expand description
Used for button press and button release events. The
type field will be one of EventType::ButtonPress,
[EventType::_2buttonPress][crate::EventType::_2buttonPress], [EventType::_3buttonPress][crate::EventType::_3buttonPress] or EventType::ButtonRelease,
Double and triple-clicks result in a sequence of events being received. For double-clicks the order of events will be:
EventType::ButtonPressEventType::ButtonReleaseEventType::ButtonPress- [
EventType::_2buttonPress][crate::EventType::_2buttonPress] EventType::ButtonRelease
Note that the first click is received just like a normal
button press, while the second click results in a [EventType::_2buttonPress][crate::EventType::_2buttonPress]
being received just after the EventType::ButtonPress.
Triple-clicks are very similar to double-clicks, except that
[EventType::_3buttonPress][crate::EventType::_3buttonPress] is inserted after the third click. The order of the
events is:
EventType::ButtonPressEventType::ButtonReleaseEventType::ButtonPress- [
EventType::_2buttonPress][crate::EventType::_2buttonPress] EventType::ButtonReleaseEventType::ButtonPress- [
EventType::_3buttonPress][crate::EventType::_3buttonPress] EventType::ButtonRelease
For a double click to occur, the second button press must occur within 1/4 of a second of the first. For a triple click to occur, the third button press must also occur within 1/2 second of the first button press.
Implementations
Methods from Deref<Target = Event>
pub fn put(&self)
pub fn axis(&self, axis_use: AxisUse) -> Option<f64>
pub fn click_count(&self) -> Option<u32>
pub fn coords(&self) -> Option<(f64, f64)>
pub fn keycode(&self) -> Option<u16>
pub fn keyval(&self) -> Option<u32>
pub fn root_coords(&self) -> Option<(f64, f64)>
pub fn scroll_direction(&self) -> Option<ScrollDirection>
pub fn scroll_deltas(&self) -> Option<(f64, f64)>
pub fn is_scroll_stop_event(&self) -> bool
pub fn state(&self) -> Option<ModifierType>
pub fn time(&self) -> u32
pub fn event_sequence(&self) -> Option<EventSequence>
pub fn seat(&self) -> Option<Seat>
pub fn scancode(&self) -> i32
pub fn is_pointer_emulated(&self) -> bool
pub fn set_screen(&mut self, screen: Option<&Screen>)
pub fn screen(&self) -> Option<Screen>
pub fn set_device(&mut self, device: Option<&Device>)
pub fn device(&self) -> Option<Device>
pub fn set_source_device(&mut self, device: Option<&Device>)
pub fn source_device(&self) -> Option<Device>
pub fn set_device_tool(&mut self, device: Option<&DeviceTool>)
pub fn device_tool(&self) -> Option<DeviceTool>
Sourcepub fn event_type(&self) -> EventType
pub fn event_type(&self) -> EventType
Returns the event type.
Sourcepub fn is_send_event(&self) -> bool
pub fn is_send_event(&self) -> bool
Returns whether the event was sent explicitly.
Sourcepub fn downcast_ref<T: FromEvent>(&self) -> Option<&T>
pub fn downcast_ref<T: FromEvent>(&self) -> Option<&T>
Tries to downcast to a specific event type.
Sourcepub fn downcast_mut<T: FromEvent>(&mut self) -> Option<&mut T>
pub fn downcast_mut<T: FromEvent>(&mut self) -> Option<&mut T>
Tries to downcast to a specific event type.