pub struct GLContext { /* private fields */ }Expand description
GLContext is an object representing the platform-specific
OpenGL drawing context.
GdkGLContexts are created for a Window using
Window::create_gl_context(), and the context will match
the Visual of the window.
A GLContext is not tied to any particular normal framebuffer.
For instance, it cannot draw to the Window back buffer. The GDK
repaint system is in full control of the painting to that. Instead,
you can create render buffers or textures and use gdk_cairo_draw_from_gl()
in the draw function of your widget to draw them. Then GDK will handle
the integration of your rendering with that of other widgets.
Support for GLContext is platform-specific, context creation
can fail, returning None context.
A GLContext has to be made “current” in order to start using
it, otherwise any OpenGL call will be ignored.
Creating a new OpenGL context
In order to create a new GLContext instance you need a
Window, which you typically get during the realize call
of a widget.
A GLContext is not realized until either make_current(),
or until it is realized using realize(). It is possible to
specify details of the GL context like the OpenGL version to be used, or
whether the GL context should have extra state validation enabled after
calling Window::create_gl_context() by calling realize().
If the realization fails you have the option to change the settings of the
GLContext and try again.
Using a GdkGLContext
You will need to make the GLContext the current context
before issuing OpenGL calls; the system sends OpenGL commands to
whichever context is current. It is possible to have multiple
contexts, so you always need to ensure that the one which you
want to draw with is the current one before issuing commands:
⚠️ The following code is in C ⚠️
gdk_gl_context_make_current (context);You can now perform your drawing using OpenGL commands.
You can check which GLContext is the current one by using
current(); you can also unset any GLContext
that is currently set by calling clear_current().
This is an Abstract Base Class, you cannot instantiate it.
Properties
display
The Display used to create the GLContext.
Readable | Writeable | Construct Only
shared-context
The GLContext that this context is sharing data with, or None
Readable | Writeable | Construct Only
window
The Window the gl context is bound to.
Readable | Writeable | Construct Only
Implementations
Sourceimpl GLContext
impl GLContext
Sourcepub fn is_debug_enabled(&self) -> bool
pub fn is_debug_enabled(&self) -> bool
Sourcepub fn is_forward_compatible(&self) -> bool
pub fn is_forward_compatible(&self) -> bool
Retrieves the value set using set_forward_compatible().
Returns
true if the context should be forward compatible
Sourcepub fn required_version(&self) -> (i32, i32)
pub fn required_version(&self) -> (i32, i32)
Retrieves the major and minor version requested by calling
set_required_version().
Returns
major
return location for the major version to request
minor
return location for the minor version to request
Sourcepub fn is_legacy(&self) -> bool
pub fn is_legacy(&self) -> bool
Whether the GLContext is in legacy mode or not.
The GLContext must be realized before calling this function.
When realizing a GL context, GDK will try to use the OpenGL 3.2 core
profile; this profile removes all the OpenGL API that was deprecated
prior to the 3.2 version of the specification. If the realization is
successful, this function will return false.
If the underlying OpenGL implementation does not support core profiles,
GDK will fall back to a pre-3.2 compatibility profile, and this function
will return true.
You can use the value returned by this function to decide which kind of OpenGL API to use, or whether to do extension discovery, or what kind of shader programs to load.
Returns
true if the GL context is in legacy mode
Sourcepub fn make_current(&self)
pub fn make_current(&self)
Makes the self the current one.
Sourcepub fn set_debug_enabled(&self, enabled: bool)
pub fn set_debug_enabled(&self, enabled: bool)
Sourcepub fn set_forward_compatible(&self, compatible: bool)
pub fn set_forward_compatible(&self, compatible: bool)
Sets whether the GLContext should be forward compatible.
Forward compatibile contexts must not support OpenGL functionality that has been marked as deprecated in the requested version; non-forward compatible contexts, on the other hand, must support both deprecated and non deprecated functionality.
The GLContext must not be realized or made current prior to calling
this function.
compatible
whether the context should be forward compatible
Sourcepub fn set_required_version(&self, major: i32, minor: i32)
pub fn set_required_version(&self, major: i32, minor: i32)
Sourcepub fn set_use_es(&self, use_es: i32)
pub fn set_use_es(&self, use_es: i32)
Requests that GDK create a OpenGL ES context instead of an OpenGL one, if the platform and windowing system allows it.
The self must not have been realized.
By default, GDK will attempt to automatically detect whether the
underlying GL implementation is OpenGL or OpenGL ES once the self
is realized.
You should check the return value of uses_es() after
calling realize() to decide whether to use the OpenGL or
OpenGL ES API, extensions, or shaders.
use_es
whether the context should use OpenGL ES instead of OpenGL, or -1 to allow auto-detection
Sourcepub fn clear_current()
pub fn clear_current()
Clears the current GLContext.
Any OpenGL call after this function returns will be ignored
until make_current() is called.