Geometry

Struct Geometry 

pub struct Geometry { /* private fields */ }
The Geometry struct gives the window manager information about a window’s geometry constraints. Normally you would set these on the GTK+ level using gtk_window_set_geometry_hints(). GtkWindow then sets the hints on the Window it creates.

Window::set_geometry_hints() expects the hints to be fully valid already and simply passes them to the window manager; in contrast, gtk_window_set_geometry_hints() performs some interpretation. For example, GtkWindow will apply the hints to the geometry widget instead of the toplevel window, if you set a geometry widget. Also, the min_width/min_height/max_width/max_height fields may be set to -1, and GtkWindow will substitute the size request of the window or geometry widget. If the minimum size hint is not provided, GtkWindow will use its requisition as the minimum size. If the minimum size is provided and a geometry widget is set, GtkWindow will take the minimum size as the minimum size of the geometry widget rather than the entire window. The base size is treated similarly.

The canonical use-case for gtk_window_set_geometry_hints() is to get a terminal widget to resize properly. Here, the terminal text area should be the geometry widget; GtkWindow will then automatically set the base size to the size of other widgets in the terminal window, such as the menubar and scrollbar. Then, the width_inc and height_inc fields should be set to the size of one character in the terminal. Finally, the base size should be set to the size of one character. The net effect is that the minimum size of the terminal will have a 1x1 character terminal area, and only terminal sizes on the “character grid” will be allowed.

Here’s an example of how the terminal example would be implemented, assuming a terminal area widget called “terminal” and a toplevel window “toplevel”:

⚠️ The following code is in C ⚠️

    GdkGeometry hints;

    hints.base_width = terminal->char_width;
        hints.base_height = terminal->char_height;
        hints.min_width = terminal->char_width;
        hints.min_height = terminal->char_height;
        hints.width_inc = terminal->char_width;
        hints.height_inc = terminal->char_height;

 gtk_window_set_geometry_hints (GTK_WINDOW (toplevel),
                                GTK_WIDGET (terminal),
                                &hints,
                                GDK_HINT_RESIZE_INC |
                                GDK_HINT_MIN_SIZE |
                                GDK_HINT_BASE_SIZE);

The other useful fields are the min_aspect and max_aspect fields; these contain a width/height ratio as a floating point number. If a geometry widget is set, the aspect applies to the geometry widget rather than the entire window. The most common use of these hints is probably to set min_aspect and max_aspect to the same value, thus forcing the window to keep a constant aspect ratio.

Implementations

Source

impl Geometry

pub fn as_ptr(&self) -> *mut GdkGeometry

pub unsafe fn from_glib_ptr_borrow<'a>(ptr: *const GdkGeometry) -> &'a Self

Borrows the underlying C value.

pub unsafe fn from_glib_ptr_borrow_mut<'a>( ptr: *mut GdkGeometry, ) -> &'a mut Self

Borrows the underlying C value mutably.

Source

impl Geometry

pub fn new( min_width: i32, min_height: i32, max_width: i32, max_height: i32, base_width: i32, base_height: i32, width_inc: i32, height_inc: i32, min_aspect: f64, max_aspect: f64, win_gravity: Gravity, ) -> Self

pub fn min_width(&self) -> i32

pub fn min_height(&self) -> i32

pub fn max_width(&self) -> i32

pub fn max_height(&self) -> i32

pub fn base_width(&self) -> i32

pub fn base_height(&self) -> i32

pub fn width_inc(&self) -> i32

pub fn height_inc(&self) -> i32

pub fn min_aspect(&self) -> f64

pub fn max_aspect(&self) -> f64

pub fn win_gravity(&self) -> Gravity