pub struct ModifierType(/* private fields */);Expand description
A set of bit-flags to indicate the state of modifier keys and mouse buttons in various event types. Typical modifier keys are Shift, Control, Meta, Super, Hyper, Alt, Compose, Apple, CapsLock or ShiftLock.
Like the X Window System, GDK supports 8 modifier keys and 5 mouse buttons.
Since 2.10, GDK recognizes which of the Meta, Super or Hyper keys are mapped
to Mod2 - Mod5, and indicates this by setting SUPER_MASK,
HYPER_MASK or META_MASK in the state field of key events.
Note that GDK may add internal values to events which include
reserved values such as MODIFIER_RESERVED_13_MASK. Your code
should preserve and ignore them. You can use MODIFIER_MASK to
remove all reserved values.
Also note that the GDK X backend interprets button press events for button
4-7 as scroll events, so BUTTON4_MASK and BUTTON5_MASK will never
be set.
Implementations
Sourceimpl ModifierType
impl ModifierType
Sourcepub const SHIFT_MASK: Self
pub const SHIFT_MASK: Self
the Shift key.
Sourcepub const LOCK_MASK: Self
pub const LOCK_MASK: Self
a Lock key (depending on the modifier mapping of the X server this may either be CapsLock or ShiftLock).
Sourcepub const CONTROL_MASK: Self
pub const CONTROL_MASK: Self
the Control key.
Sourcepub const MOD1_MASK: Self
pub const MOD1_MASK: Self
the fourth modifier key (it depends on the modifier mapping of the X server which key is interpreted as this modifier, but normally it is the Alt key).
Sourcepub const MOD2_MASK: Self
pub const MOD2_MASK: Self
the fifth modifier key (it depends on the modifier mapping of the X server which key is interpreted as this modifier).
Sourcepub const MOD3_MASK: Self
pub const MOD3_MASK: Self
the sixth modifier key (it depends on the modifier mapping of the X server which key is interpreted as this modifier).
Sourcepub const MOD4_MASK: Self
pub const MOD4_MASK: Self
the seventh modifier key (it depends on the modifier mapping of the X server which key is interpreted as this modifier).
Sourcepub const MOD5_MASK: Self
pub const MOD5_MASK: Self
the eighth modifier key (it depends on the modifier mapping of the X server which key is interpreted as this modifier).
Sourcepub const BUTTON1_MASK: Self
pub const BUTTON1_MASK: Self
the first mouse button.
Sourcepub const BUTTON2_MASK: Self
pub const BUTTON2_MASK: Self
the second mouse button.
Sourcepub const BUTTON3_MASK: Self
pub const BUTTON3_MASK: Self
the third mouse button.
Sourcepub const BUTTON4_MASK: Self
pub const BUTTON4_MASK: Self
the fourth mouse button.
Sourcepub const BUTTON5_MASK: Self
pub const BUTTON5_MASK: Self
the fifth mouse button.
Sourcepub const MODIFIER_RESERVED_13_MASK: Self
pub const MODIFIER_RESERVED_13_MASK: Self
A reserved bit flag; do not use in your own code
Sourcepub const MODIFIER_RESERVED_14_MASK: Self
pub const MODIFIER_RESERVED_14_MASK: Self
A reserved bit flag; do not use in your own code
Sourcepub const MODIFIER_RESERVED_15_MASK: Self
pub const MODIFIER_RESERVED_15_MASK: Self
A reserved bit flag; do not use in your own code
Sourcepub const MODIFIER_RESERVED_16_MASK: Self
pub const MODIFIER_RESERVED_16_MASK: Self
A reserved bit flag; do not use in your own code
Sourcepub const MODIFIER_RESERVED_17_MASK: Self
pub const MODIFIER_RESERVED_17_MASK: Self
A reserved bit flag; do not use in your own code
Sourcepub const MODIFIER_RESERVED_18_MASK: Self
pub const MODIFIER_RESERVED_18_MASK: Self
A reserved bit flag; do not use in your own code
Sourcepub const MODIFIER_RESERVED_19_MASK: Self
pub const MODIFIER_RESERVED_19_MASK: Self
A reserved bit flag; do not use in your own code
Sourcepub const MODIFIER_RESERVED_20_MASK: Self
pub const MODIFIER_RESERVED_20_MASK: Self
A reserved bit flag; do not use in your own code
Sourcepub const MODIFIER_RESERVED_21_MASK: Self
pub const MODIFIER_RESERVED_21_MASK: Self
A reserved bit flag; do not use in your own code
Sourcepub const MODIFIER_RESERVED_22_MASK: Self
pub const MODIFIER_RESERVED_22_MASK: Self
A reserved bit flag; do not use in your own code
Sourcepub const MODIFIER_RESERVED_23_MASK: Self
pub const MODIFIER_RESERVED_23_MASK: Self
A reserved bit flag; do not use in your own code
Sourcepub const MODIFIER_RESERVED_24_MASK: Self
pub const MODIFIER_RESERVED_24_MASK: Self
A reserved bit flag; do not use in your own code
Sourcepub const MODIFIER_RESERVED_25_MASK: Self
pub const MODIFIER_RESERVED_25_MASK: Self
A reserved bit flag; do not use in your own code
Sourcepub const SUPER_MASK: Self
pub const SUPER_MASK: Self
the Super modifier. Since 2.10
Sourcepub const HYPER_MASK: Self
pub const HYPER_MASK: Self
the Hyper modifier. Since 2.10
Sourcepub const MODIFIER_RESERVED_29_MASK: Self
pub const MODIFIER_RESERVED_29_MASK: Self
A reserved bit flag; do not use in your own code
Sourcepub const RELEASE_MASK: Self
pub const RELEASE_MASK: Self
not used in GDK itself. GTK+ uses it to differentiate between (keyval, modifiers) pairs from key press and release events.
Sourcepub const MODIFIER_MASK: Self
pub const MODIFIER_MASK: Self
a mask covering all modifier types.
Sourceimpl ModifierType
impl ModifierType
Sourcepub const fn bits(&self) -> u32
pub const fn bits(&self) -> u32
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u32) -> Option<Self>
pub const fn from_bits(bits: u32) -> Option<Self>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u32) -> Self
pub const fn from_bits_truncate(bits: u32) -> Self
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u32) -> Self
pub const fn from_bits_retain(bits: u32) -> Self
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<Self>
pub fn from_name(name: &str) -> Option<Self>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: Self) -> bool
pub const fn intersects(&self, other: Self) -> bool
Whether any set bits in other are also set in self.
Sourcepub const fn contains(&self, other: Self) -> bool
pub const fn contains(&self, other: Self) -> bool
Whether all set bits in other are also set in self.
Sourcepub fn remove(&mut self, other: Self)
pub fn remove(&mut self, other: Self)
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: Self)
pub fn toggle(&mut self, other: Self)
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub fn set(&mut self, other: Self, value: bool)
pub fn set(&mut self, other: Self, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: Self) -> Self
pub const fn intersection(self, other: Self) -> Self
The bitwise and (&) of the bits in self and other.
Sourcepub const fn union(self, other: Self) -> Self
pub const fn union(self, other: Self) -> Self
The bitwise or (|) of the bits in self and other.
Sourcepub const fn difference(self, other: Self) -> Self
pub const fn difference(self, other: Self) -> Self
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: Self) -> Self
pub const fn symmetric_difference(self, other: Self) -> Self
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub const fn complement(self) -> Self
pub const fn complement(self) -> Self
The bitwise negation (!) of the bits in self, truncating the result.
Sourceimpl ModifierType
impl ModifierType
Sourcepub const fn iter(&self) -> Iter<ModifierType> ⓘ
pub const fn iter(&self) -> Iter<ModifierType> ⓘ
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<ModifierType> ⓘ
pub const fn iter_names(&self) -> IterNames<ModifierType> ⓘ
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.