pub struct Screen { /* private fields */ }Expand description
Screen objects are the GDK representation of the screen on
which windows can be displayed and on which the pointer moves.
X originally identified screens with physical screens, but
nowadays it is more common to have a single Screen which
combines several physical monitors (see gdk_screen_get_n_monitors()).
GdkScreen is used throughout GDK and GTK+ to specify which screen
the top level windows are to be displayed on. it is also used to
query the screen specification and default settings such as
the default visual (system_visual()), the dimensions
of the physical monitors (gdk_screen_get_monitor_geometry()), etc.
Properties
font-options
Readable | Writeable
resolution
Readable | Writeable
Signals
composited-changed
The ::composited-changed signal is emitted when the composited status of the screen changes
monitors-changed
The ::monitors-changed signal is emitted when the number, size or position of the monitors attached to the screen change.
Only for X11 and OS X for now. A future implementation for Win32 may be a possibility.
size-changed
The ::size-changed signal is emitted when the pixel width or height of a screen changes.
Implementations
Sourceimpl Screen
impl Screen
Sourcepub fn resolution(&self) -> f64
pub fn resolution(&self) -> f64
Gets the resolution for font handling on the screen; see
set_resolution() for full details.
Returns
the current resolution, or -1 if no resolution has been set.
Sourcepub fn rgba_visual(&self) -> Option<Visual>
pub fn rgba_visual(&self) -> Option<Visual>
Gets a visual to use for creating windows with an alpha channel.
The windowing system on which GTK+ is running
may not support this capability, in which case None will
be returned. Even if a non-None value is returned, its
possible that the window’s alpha channel won’t be honored
when displaying the window on the screen: in particular, for
X an appropriate windowing manager and compositing manager
must be running to provide appropriate display.
This functionality is not implemented in the Windows backend.
For setting an overall opacity for a top-level window, see
Window::set_opacity().
Returns
a visual to use for windows
with an alpha channel or None if the capability is not
available.
Sourcepub fn root_window(&self) -> Option<Window>
pub fn root_window(&self) -> Option<Window>
Sourcepub fn system_visual(&self) -> Option<Visual>
pub fn system_visual(&self) -> Option<Visual>
Get the system’s default visual for self.
This is the visual for the root window of the display.
The return value should not be freed.
Returns
the system visual
Sourcepub fn toplevel_windows(&self) -> Vec<Window>
pub fn toplevel_windows(&self) -> Vec<Window>
Obtains a list of all toplevel windows known to GDK on the screen self.
A toplevel window is a child of the root window (see
gdk_get_default_root_window()).
The returned list should be freed with g_list_free(), but
its elements need not be freed.
Returns
list of toplevel windows, free with g_list_free()
Sourcepub fn window_stack(&self) -> Vec<Window>
pub fn window_stack(&self) -> Vec<Window>
Returns a GList of GdkWindows representing the current
window stack.
On X11, this is done by inspecting the _NET_CLIENT_LIST_STACKING
property on the root window, as described in the
Extended Window Manager Hints.
If the window manager does not support the
_NET_CLIENT_LIST_STACKING hint, this function returns None.
On other platforms, this function may return None, depending on whether
it is implementable on that platform.
The returned list is newly allocated and owns references to the
windows it contains, so it should be freed using g_list_free() and
its windows unrefed using g_object_unref() when no longer needed.
Returns
a
list of GdkWindows for the current window stack, or None.
Sourcepub fn is_composited(&self) -> bool
pub fn is_composited(&self) -> bool
Returns whether windows with an RGBA visual can reasonably be expected to have their alpha channel drawn correctly on the screen.
On X11 this function returns whether a compositing manager is
compositing self.
Returns
Whether windows with RGBA visuals can reasonably be expected to have their alpha channels drawn correctly on the screen.
Sourcepub fn list_visuals(&self) -> Vec<Visual>
pub fn list_visuals(&self) -> Vec<Visual>
Lists the available visuals for the specified self.
A visual describes a hardware image data format.
For example, a visual might support 24-bit color, or 8-bit color,
and might expect pixels to be in a certain format.
Call g_list_free() on the return value when you’re finished with it.
Returns
a list of visuals; the list must be freed, but not its contents
Sourcepub fn set_font_options(&self, options: Option<&FontOptions>)
pub fn set_font_options(&self, options: Option<&FontOptions>)
Sets the default font options for the screen. These
options will be set on any pango::Context’s newly created
with pango_context_get_for_screen(). Changing the
default set of font options does not affect contexts that
have already been created.
options
a cairo::FontOptions, or None to unset any
previously set default font options.
Sourcepub fn set_resolution(&self, dpi: f64)
pub fn set_resolution(&self, dpi: f64)
Sets the resolution for font handling on the screen. This is a
scale factor between points specified in a PangoFontDescription
and cairo units. The default value is 96, meaning that a 10 point
font will be 13 units high. (10 * 96. / 72. = 13.3).
dpi
the resolution in “dots per inch”. (Physical inches aren’t actually involved; the terminology is conventional.)
Sourcepub fn connect_composited_changed<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_composited_changed<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
The ::composited-changed signal is emitted when the composited status of the screen changes
Sourcepub fn connect_monitors_changed<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_monitors_changed<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
The ::monitors-changed signal is emitted when the number, size or position of the monitors attached to the screen change.
Only for X11 and OS X for now. A future implementation for Win32 may be a possibility.
Sourcepub fn connect_size_changed<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_size_changed<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
The ::size-changed signal is emitted when the pixel width or height of a screen changes.
pub fn connect_font_options_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
pub fn connect_resolution_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Sourceimpl Screen
impl Screen
Sourcepub fn font_options(&self) -> Option<FontOptions>
pub fn font_options(&self) -> Option<FontOptions>
Gets any options previously set with set_font_options().
Returns
the current font options, or None if no
default font options have been set.
pub fn setting(&self, name: &str) -> Option<Value>