pub struct Visual { /* private fields */ }Expand description
A Visual contains information about
a particular visual.
Implementations
Sourceimpl Visual
impl Visual
Sourcepub fn blue_pixel_details(&self) -> (u32, i32, i32)
pub fn blue_pixel_details(&self) -> (u32, i32, i32)
Obtains values that are needed to calculate blue pixel values in TrueColor and DirectColor. The “mask” is the significant bits within the pixel. The “shift” is the number of bits left we must shift a primary for it to be in position (according to the “mask”). Finally, “precision” refers to how much precision the pixel value contains for a particular primary.
Returns
mask
A pointer to a guint32 to be filled in, or None
shift
A pointer to a gint to be filled in, or None
precision
A pointer to a gint to be filled in, or None
Sourcepub fn green_pixel_details(&self) -> (u32, i32, i32)
pub fn green_pixel_details(&self) -> (u32, i32, i32)
Obtains values that are needed to calculate green pixel values in TrueColor and DirectColor. The “mask” is the significant bits within the pixel. The “shift” is the number of bits left we must shift a primary for it to be in position (according to the “mask”). Finally, “precision” refers to how much precision the pixel value contains for a particular primary.
Returns
mask
A pointer to a guint32 to be filled in, or None
shift
A pointer to a gint to be filled in, or None
precision
A pointer to a gint to be filled in, or None
Sourcepub fn red_pixel_details(&self) -> (u32, i32, i32)
pub fn red_pixel_details(&self) -> (u32, i32, i32)
Obtains values that are needed to calculate red pixel values in TrueColor and DirectColor. The “mask” is the significant bits within the pixel. The “shift” is the number of bits left we must shift a primary for it to be in position (according to the “mask”). Finally, “precision” refers to how much precision the pixel value contains for a particular primary.
Returns
mask
A pointer to a guint32 to be filled in, or None
shift
A pointer to a gint to be filled in, or None
precision
A pointer to a gint to be filled in, or None
Sourcepub fn visual_type(&self) -> VisualType
pub fn visual_type(&self) -> VisualType
Returns the type of visual this is (PseudoColor, TrueColor, etc).
Returns
A VisualType stating the type of self.