pub struct WindowState(/* private fields */);Expand description
Specifies the state of a toplevel window.
Implementations
Sourceimpl WindowState
impl WindowState
Sourcepub const FULLSCREEN: Self
pub const FULLSCREEN: Self
the window is maximized without decorations.
Sourcepub const TILED: Self
pub const TILED: Self
the window is in a tiled state, Since 3.10. Since 3.22.23, this is deprecated in favor of per-edge information.
Sourcepub const TOP_RESIZABLE: Self
pub const TOP_RESIZABLE: Self
whether the top edge is resizable, Since 3.22.23
Sourcepub const RIGHT_TILED: Self
pub const RIGHT_TILED: Self
whether the right edge is tiled, Since 3.22.23
Sourcepub const RIGHT_RESIZABLE: Self
pub const RIGHT_RESIZABLE: Self
whether the right edge is resizable, Since 3.22.23
Sourcepub const BOTTOM_TILED: Self
pub const BOTTOM_TILED: Self
whether the bottom edge is tiled, Since 3.22.23
Sourcepub const BOTTOM_RESIZABLE: Self
pub const BOTTOM_RESIZABLE: Self
whether the bottom edge is resizable, Since 3.22.23
Sourcepub const LEFT_TILED: Self
pub const LEFT_TILED: Self
whether the left edge is tiled, Since 3.22.23
Sourcepub const LEFT_RESIZABLE: Self
pub const LEFT_RESIZABLE: Self
whether the left edge is resizable, Since 3.22.23
Sourceimpl WindowState
impl WindowState
Sourcepub const fn bits(&self) -> u32
pub const fn bits(&self) -> u32
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u32) -> Option<Self>
pub const fn from_bits(bits: u32) -> Option<Self>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u32) -> Self
pub const fn from_bits_truncate(bits: u32) -> Self
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u32) -> Self
pub const fn from_bits_retain(bits: u32) -> Self
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<Self>
pub fn from_name(name: &str) -> Option<Self>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: Self) -> bool
pub const fn intersects(&self, other: Self) -> bool
Whether any set bits in other are also set in self.
Sourcepub const fn contains(&self, other: Self) -> bool
pub const fn contains(&self, other: Self) -> bool
Whether all set bits in other are also set in self.
Sourcepub fn remove(&mut self, other: Self)
pub fn remove(&mut self, other: Self)
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: Self)
pub fn toggle(&mut self, other: Self)
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub fn set(&mut self, other: Self, value: bool)
pub fn set(&mut self, other: Self, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: Self) -> Self
pub const fn intersection(self, other: Self) -> Self
The bitwise and (&) of the bits in self and other.
Sourcepub const fn union(self, other: Self) -> Self
pub const fn union(self, other: Self) -> Self
The bitwise or (|) of the bits in self and other.
Sourcepub const fn difference(self, other: Self) -> Self
pub const fn difference(self, other: Self) -> Self
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: Self) -> Self
pub const fn symmetric_difference(self, other: Self) -> Self
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub const fn complement(self) -> Self
pub const fn complement(self) -> Self
The bitwise negation (!) of the bits in self, truncating the result.
Sourceimpl WindowState
impl WindowState
Sourcepub const fn iter(&self) -> Iter<WindowState> ⓘ
pub const fn iter(&self) -> Iter<WindowState> ⓘ
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<WindowState> ⓘ
pub const fn iter_names(&self) -> IterNames<WindowState> ⓘ
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.